%plots impulse responses for all shocks
%if you want different parameter values go and change them in all 4 .mod
%files (ctw, finfric, unempl and baseline) and then run this file

clear all
clc

cd ..
cd CTW
dynare ctw_employer_surplus

cd ..
cd Baseline
dynare baseline
cd ..
cd Unempl
dynare unempl
disp('only finfric left');
cd ..
cd FinFric
dynare finfric
cd ..

clear all
clc

cd CTW
load ctw_oo_irfs
load ctw_employer_surplus_results
spread= M_.params(	193	);

cd ..
cd FinFric
load finfric_oo_irfs 
cd ..
cd Baseline
load baseline_oo_irfs 
cd ..
cd Unempl
load unempl_oo_irfs 
cd ..
cd Plots


varnames=['Nom. Interest Rate (ABP)  '
    'CPI Inflation (ABP)       '
    'GDP (% dev.)              '
    'Consumption (% dev.)      '
    'Investment (% dev.)       '
    'Net Exports/Y (Lev. dev.) '
    'Total Hours (% dev.)      '
    'Hours / Employee (% dev.) '
    'Unempl. Rate (Lev. dev.)  '
    'Real Nash Wage (% dev.)   '
    'Shadow Wage, MPL (% dev.) ' 
    'Nom. Exch. Rate (% dev.)  '
    'Net Worth (% dev.)        '
    'Spread (ABP)              '];

shock_names=[
'muz_eps     '
%'mupsi_eps   '
'epsilon_eps '
'Upsilon_eps '
'zetac_eps   '
'zetah_eps   '
'phitilde_eps'
'epsR_eps    '
'g_eps       '
'taud_eps    '
'taux_eps    '
'taumc_eps   '
'taumi_eps   '
'taumx_eps   '
'gamma_eps   '
%'sigma_eps   '
%'eta_eps     '
'ystar_eps   '
'pistar_eps  '
'Rstar_eps   '];    

shock_fullnames=[
'Unit-root Neutral Technology Shock     '
%'Unit-root Investment Technology Shock  '
'Stationary Neutral Technology Shock    '
'Marginal Efficiency of Investment Shock'
'Consumption Preference Shock           '
'Labor Preference Shock                 '
'Country Risk Premium Shock             '
'Monetary Policy Shock                  '
'Government Consumption Shock           '
'Domestic Markup Shock                  '
'Export Markup Shock                    '
'Import Consumption Markup Shock        '
'Import Investment Markup Shock         '
'Import Export Markup Shock             '
'Entrepreneur Wealth Shock              '
%'Entrepreneur Risk Shock                '
%'Bargaining Power of Workers Shock      '
'Foreign Output Shock                   '
'Foreign Inflation Shock                '
'Foreign Nominal Interest Rate Shock    ']; 

for index=1:1:size(shock_names,1),         
    if (index==1)   % i.e. unit root shock
        zt=cumsum(ctw_oo_irfs.lmuzplusU_muz_eps);
        ctw_shock=100*[eval(['ctw_oo_irfs.data_RU_',shock_names(index,:)])
            eval(['ctw_oo_irfs.data_picU_',shock_names(index,:)])
            eval(['zt+ctw_oo_irfs.lylessdU_',shock_names(index,:)])    
            eval(['zt+ctw_oo_irfs.lcU_',shock_names(index,:)])
            eval(['zt+ctw_oo_irfs.liU_',shock_names(index,:)])
            eval(['ctw_oo_irfs.nxdivGDPU_',shock_names(index,:)]) 
            eval(['ctw_oo_irfs.lHU_',shock_names(index,:)])
            eval(['ctw_oo_irfs.lintensity0U_',shock_names(index,:)])
            eval(['(1-L)*ctw_oo_irfs.lUnemprateU_',shock_names(index,:)])
            eval(['zt+ctw_oo_irfs.lavg_NashU_',shock_names(index,:)])
            eval(['zt+ctw_oo_irfs.lwbarU_',shock_names(index,:)])
            eval(['ctw_oo_irfs.lSlevU_',shock_names(index,:)])   
            eval(['zt+ctw_oo_irfs.lnU_',shock_names(index,:)])
            eval(['400*spread*ctw_oo_irfs.lspreadU_',shock_names(index,:)])
            ];
    else
        ctw_shock=100*[eval(['ctw_oo_irfs.data_RU_',shock_names(index,:)])
            eval(['ctw_oo_irfs.data_picU_',shock_names(index,:)])
            eval(['ctw_oo_irfs.lylessdU_',shock_names(index,:)])   
            eval(['ctw_oo_irfs.lcU_',shock_names(index,:)])
            eval(['ctw_oo_irfs.liU_',shock_names(index,:)])
            eval(['ctw_oo_irfs.nxdivGDPU_',shock_names(index,:)])
            eval(['ctw_oo_irfs.lHU_',shock_names(index,:)])
            eval(['ctw_oo_irfs.lintensity0U_',shock_names(index,:)])
            eval(['(1-L)*ctw_oo_irfs.lUnemprateU_',shock_names(index,:)])
            eval(['ctw_oo_irfs.lavg_NashU_',shock_names(index,:)])
            eval(['ctw_oo_irfs.lwbarU_',shock_names(index,:)])
            eval(['ctw_oo_irfs.lSlevU_',shock_names(index,:)])   % lqU_
            eval(['ctw_oo_irfs.lnU_',shock_names(index,:)])
            eval(['400*spread*ctw_oo_irfs.lspreadU_',shock_names(index,:)])
            ];
    end

    if shock_names(index,:)=='gamma_eps   ' | shock_names(index,:)=='sigma_eps   '
        unempl_shock=NaN*ctw_shock;
    else
        
        if (index==1)   % i.e. unit root shock
            unempl_shock=100*[eval(['unempl_oo_irfs.data_RU_',shock_names(index,:)])
                eval(['unempl_oo_irfs.data_picU_',shock_names(index,:)])
                eval(['zt+unempl_oo_irfs.lylessdU_',shock_names(index,:)])
                eval(['zt+unempl_oo_irfs.lcU_',shock_names(index,:)])
                eval(['zt+unempl_oo_irfs.liU_',shock_names(index,:)])
                eval(['unempl_oo_irfs.nxdivGDPU_',shock_names(index,:)])
                eval(['unempl_oo_irfs.lHU_',shock_names(index,:)])
                eval(['unempl_oo_irfs.lintensity0U_',shock_names(index,:)])
                eval(['(1-L)*unempl_oo_irfs.lUnemprateU_',shock_names(index,:)])
                eval(['zt+unempl_oo_irfs.lavg_NashU_',shock_names(index,:)])
                eval(['zt+unempl_oo_irfs.lwbarU_',shock_names(index,:)])
                eval(['unempl_oo_irfs.lSlevU_',shock_names(index,:)])
                eval(['NaN*unempl_oo_irfs.liU_',shock_names(index,:)])
                eval(['NaN*unempl_oo_irfs.liU_',shock_names(index,:)])
                ];
        else
            unempl_shock=100*[eval(['unempl_oo_irfs.data_RU_',shock_names(index,:)])
                eval(['unempl_oo_irfs.data_picU_',shock_names(index,:)])
                eval(['unempl_oo_irfs.lylessdU_',shock_names(index,:)]) 
                eval(['unempl_oo_irfs.lcU_',shock_names(index,:)])
                eval(['unempl_oo_irfs.liU_',shock_names(index,:)])
                eval(['unempl_oo_irfs.nxdivGDPU_',shock_names(index,:)])
                eval(['unempl_oo_irfs.lHU_',shock_names(index,:)])
                eval(['unempl_oo_irfs.lintensity0U_',shock_names(index,:)])
                eval(['(1-L)*unempl_oo_irfs.lUnemprateU_',shock_names(index,:)])
                eval(['unempl_oo_irfs.lavg_NashU_',shock_names(index,:)])
                eval(['unempl_oo_irfs.lwbarU_',shock_names(index,:)])
                eval(['unempl_oo_irfs.lSlevU_',shock_names(index,:)])
                eval(['NaN*unempl_oo_irfs.liU_',shock_names(index,:)])
                eval(['NaN*unempl_oo_irfs.liU_',shock_names(index,:)])
                ];
        end
end

if shock_names(index,:)=='eta_eps     '
    finfric_shock=NaN*ctw_shock;
else
    if (index==1)   % i.e. unit root shock        
        finfric_shock=100*[eval(['finfric_oo_irfs.data_RU_',shock_names(index,:)])
            eval(['finfric_oo_irfs.data_picU_',shock_names(index,:)])
            eval(['zt+finfric_oo_irfs.lylessdU_',shock_names(index,:)])    %   eval(['finfric_oo_irfs.lylessdU_',shock_names(index,:)])
            eval(['zt+finfric_oo_irfs.lcU_',shock_names(index,:)])
            eval(['zt+finfric_oo_irfs.liU_',shock_names(index,:)])
            eval(['finfric_oo_irfs.nxdivGDPU_',shock_names(index,:)])
            eval(['finfric_oo_irfs.lHU_',shock_names(index,:)])
            eval(['NaN*finfric_oo_irfs.lHU_',shock_names(index,:)]) % intensity
            eval(['NaN*finfric_oo_irfs.lHU_',shock_names(index,:)]) % unemp
            eval(['zt+finfric_oo_irfs.lwbarU_',shock_names(index,:)]) % this is the "worker's wage", in CTW: eval(['ctw_oo_irfs.lavg_NashU_',shock_names(index,:)])
            eval(['NaN*finfric_oo_irfs.lwbarU_',shock_names(index,:)]) % shadow wage
            eval(['finfric_oo_irfs.lSlevU_',shock_names(index,:)])
            eval(['zt+finfric_oo_irfs.lnU_',shock_names(index,:)])
            eval(['400*spread*finfric_oo_irfs.lspreadU_',shock_names(index,:)])
            ];
    else
        finfric_shock=100*[eval(['finfric_oo_irfs.data_RU_',shock_names(index,:)])
            eval(['finfric_oo_irfs.data_picU_',shock_names(index,:)])
            eval(['finfric_oo_irfs.lylessdU_',shock_names(index,:)])    
            eval(['finfric_oo_irfs.lcU_',shock_names(index,:)])
            eval(['finfric_oo_irfs.liU_',shock_names(index,:)])
            eval(['finfric_oo_irfs.nxdivGDPU_',shock_names(index,:)])
            eval(['finfric_oo_irfs.lHU_',shock_names(index,:)])
            eval(['NaN*finfric_oo_irfs.lHU_',shock_names(index,:)]) % intensity
            eval(['NaN*finfric_oo_irfs.lHU_',shock_names(index,:)]) % unemp
            eval(['finfric_oo_irfs.lwbarU_',shock_names(index,:)]) % this is the "worker's wage", in CTW: eval(['ctw_oo_irfs.lavg_NashU_',shock_names(index,:)])
            eval(['NaN*finfric_oo_irfs.lwbarU_',shock_names(index,:)]) % shadow wage
            eval(['finfric_oo_irfs.lSlevU_',shock_names(index,:)])
            eval(['finfric_oo_irfs.lnU_',shock_names(index,:)])
            eval(['400*spread*finfric_oo_irfs.lspreadU_',shock_names(index,:)])
            ];
    end
    
end

if shock_names(index,:)=='gamma_eps   ' | shock_names(index,:)=='sigma_eps   ' | shock_names(index,:)=='eta_eps     '
baseline_shock=NaN*ctw_shock;
else
    if (index==1)   % i.e. unit root shock
        baseline_shock=100*[eval(['baseline_oo_irfs.data_RU_',shock_names(index,:)])
            eval(['baseline_oo_irfs.data_picU_',shock_names(index,:)])
            eval(['zt+baseline_oo_irfs.lylessdU_',shock_names(index,:)])
            eval(['zt+baseline_oo_irfs.lcU_',shock_names(index,:)])
            eval(['zt+baseline_oo_irfs.liU_',shock_names(index,:)])
            eval(['baseline_oo_irfs.nxdivGDPU_',shock_names(index,:)])
            eval(['baseline_oo_irfs.lHU_',shock_names(index,:)])
            eval(['NaN*baseline_oo_irfs.lHU_',shock_names(index,:)]) % intensity
            eval(['NaN*baseline_oo_irfs.lHU_',shock_names(index,:)]) % unemp
            eval(['zt+baseline_oo_irfs.lwbarU_',shock_names(index,:)]) % this is the "worker's wage", in CTW: eval(['ctw_oo_irfs.lavg_NashU_',shock_names(index,:)])
            eval(['NaN*baseline_oo_irfs.lwbarU_',shock_names(index,:)]) % shadow wage
            eval(['baseline_oo_irfs.lSlevU_',shock_names(index,:)])
            eval(['NaN*baseline_oo_irfs.lqU_',shock_names(index,:)])    % net worth
            eval(['NaN*baseline_oo_irfs.lqU_',shock_names(index,:)])    % spread
            ];
    else
        baseline_shock=100*[eval(['baseline_oo_irfs.data_RU_',shock_names(index,:)])
            eval(['baseline_oo_irfs.data_picU_',shock_names(index,:)])
            eval(['baseline_oo_irfs.lylessdU_',shock_names(index,:)])
            eval(['baseline_oo_irfs.lcU_',shock_names(index,:)])
            eval(['baseline_oo_irfs.liU_',shock_names(index,:)])
            eval(['baseline_oo_irfs.nxdivGDPU_',shock_names(index,:)])
            eval(['baseline_oo_irfs.lHU_',shock_names(index,:)])
            eval(['NaN*baseline_oo_irfs.lHU_',shock_names(index,:)]) % intensity
            eval(['NaN*baseline_oo_irfs.lHU_',shock_names(index,:)]) % unemp
            eval(['baseline_oo_irfs.lwbarU_',shock_names(index,:)]) % this is the "worker's wage", in CTW: eval(['ctw_oo_irfs.lavg_NashU_',shock_names(index,:)])
            eval(['NaN*baseline_oo_irfs.lwbarU_',shock_names(index,:)]) % shadow wage
            eval(['baseline_oo_irfs.lSlevU_',shock_names(index,:)])
            eval(['NaN*baseline_oo_irfs.lqU_',shock_names(index,:)])    % net worth
            eval(['NaN*baseline_oo_irfs.lqU_',shock_names(index,:)])    % spread
            ];
    end
end

time=0:1:size(ctw_shock,2)-1;

figure('Name',shock_fullnames(index,:)); 
for jj=1:1:size(ctw_shock,1),
    subplot(5,3,jj)
    plot(time,ctw_shock(jj,:),'r-','LineWidth',3); hold on
    plot(time,finfric_shock(jj,:),'b-.','LineWidth',2); hold on
    plot(time,unempl_shock(jj,:),'g--','LineWidth',2); hold on
    plot(time,baseline_shock(jj,:),'k:','LineWidth',2); hold off  
    
    if jj==12,
        legend('Full Model','Financial Friction Model','Employment Friction Model','Baseline Model','Location','SouthOutside');   
        legend('boxoff');
    end
    
    set(gca,'FontSize',11);
    if jj<12
        set(gca,'XTicklabel',[]);
    end
    title(varnames(jj,:));
    axis tight;
end;

suptitle(shock_fullnames(index,:));

print('-depsc','-zbuffer',['impresp_',shock_names(index,1:5)]);
print('-dpdf',['impresp_',shock_names(index,1:5)]);

end
