function [lnpriormom] = mother_new(data,Pstar,H,bayestopt_,T,trend)

% Code to implement notes on endogenous priors by Lawrence Christiano,
% specified in the appendix of:
% Introducing Financial Frictions and Unemployment into a Small Open Economy Model
% by Lawrence J. Christiano, Mathias Trabandt and Karl Walentin,
% Journal of Economic Dynamics and Control      

% call this function from DSGElikelihood.m with the following lines at the
% very end of that file:
% lnpriormom = mother_new(data,Pstar,H,bayestopt_,T,trend);
% fval    = (likelihood-lnpriormom-lnprior);

%this is the 'mother' of the priors on the model parameters.
%the priors include a metric across some choosen moments of the (supposedly
%pre-sample) data.
% *** Implemented file for variances, but in principle any moment
% *** could be matched
%As a default, the prior second moments are computed from the same sample
%used to find the posterior mode. This could be changed by making the
%appropriate adjustment to the following code.

Y=data(:,1:end)';
Tsamp=size(Y,1);    % sample length
n=size(Y,2);        % number of matched moments: here set equal to nr of observables

Fhat=zeros(n,1);
hmat=zeros(n,Tsamp);
Ydemean=zeros(Tsamp,n);
C0=zeros(n,n);
C1=zeros(n,n);
C2=zeros(n,n);

for j=1:n
    Ydemean(:,j)=Y(:,j)-mean(Y(:,j));
end
Fhat=diag(Ydemean'*Ydemean)/Tsamp;

% we need ht, where t=1,...,T
for t=1:Tsamp
    hmat(:,t)=diag(Ydemean(t,:)'*Ydemean(t,:))-Fhat;
end

% To calculate Shat we need C0, C1 and C2
for t=1:Tsamp
    C0=C0+1/Tsamp*hmat(:,t)*hmat(:,t)';
end

for t=2:Tsamp
    C1=C1+1/(Tsamp-1)*hmat(:,t)*hmat(:,t-1)';
end

for t=3:Tsamp
    C2=C2+1/(Tsamp-2)*hmat(:,t)*hmat(:,t-2)';
end

% Finally, we have the sampling uncertainty measure Shat:
Shat=C0 +(1-1/(2+1))*(C1+C1')...
    +(1-2/(2+1))*(C2+C2');

% Model variances below:
mf=bayestopt_.mf;
II=eye(size(T,2));
Z=II(mf,:);
%Ey=trend(:,1);
% This is Ftheta, variance of model variables, given param vector theta:
Ftheta=diag(Z*Pstar(:,mf));  % +H+Ey*Ey');

% below commented out line is for Del Negro Schorfheide style priors:
%     lnpriormom=-.5*n*TT*log(2*pi)-.5*TT*log(det(sigma))-.5*TT*trace(inv(sigma)*(gamyy-2*phi'*gamxy+phi'*gamxx*phi));
lnpriormom=.5*n*log(Tsamp/(2*pi))-.5*log(det(Shat))-.5*Tsamp*(Fhat-Ftheta)'*inv(Shat)*(Fhat-Ftheta);

