% Script to plot IRFs after main model has been run in Dynare.

varnames=['Nom. Interest Rate (ABP)  '
          'CPI Inflation (ABP)       '
          'Output (% dev.)           '
          'Consumtion (% dev.)       '
          'Investment (% dev.)       '
          'Net Exports/Y (Lev. dev.) '
          'Total Hours (% dev.)      '
          'Hours/Employee(0)(% dev.) '
          'Unempl.Rate (Lev. dev.)   '
          'Real Nash wage (% dev)    ' 
          'Shadow wage, MPL (% dev)  ' 
          'Nom. Exch. Rate (% dev.)  '
          'Net Worth (% dev.)        '
          'Risk Spread (ABP)         '
          'Net For. Assets(Lev. dev.)'];  % bonus variable, not present in across models plot
          
global M_;
spread= M_.params(	193	);
      

%Monetary policy shock
figure; 
ctw_Rshock=100*[data_RU_epsR_eps' 
     data_picU_epsR_eps'
     lylessdU_epsR_eps'
     lcU_epsR_eps'
     liU_epsR_eps'
     nxdivGDPU_epsR_eps' 
     lHU_epsR_eps'
     lintensity0U_epsR_eps'     
     (1-L)*lUnemprateU_epsR_eps'
     lavg_NashU_epsR_eps'
     lwbarU_epsR_eps'
     lSlevU_epsR_eps'  
     lnU_epsR_eps' 
     400*spread*lspreadU_epsR_eps'
     aU_epsR_eps'];
time=0:1:size(ctw_Rshock,2)-1;
for jj=1:1:size(ctw_Rshock,1),
subplot(5,3,jj)
plot(time,ctw_Rshock(jj,:),time,0*time,'--','LineWidth',2);
set(gca,'FontSize',11);
if jj<10
 set(gca,'XTicklabel',[]);
end

title(varnames(jj,:));
axis tight;
end;
suptitle('Monetary Policy Shock');
print('-depsc','-zbuffer','impresp_Rshock');
print('-dpdf','-zbuffer','impresp_Rshock'); 


%Stationary Technology Shock
figure
ctw_epsilonshock=100*[data_RU_epsilon_eps' 
     data_picU_epsilon_eps'
     lylessdU_epsilon_eps'
     lcU_epsilon_eps'
     liU_epsilon_eps'
     nxdivGDPU_epsilon_eps'  
     lHU_epsilon_eps'
     lintensity0U_epsilon_eps'     
     (1-L)*lUnemprateU_epsilon_eps'
     lavg_NashU_epsilon_eps'
     lwbarU_epsilon_eps'
     lSlevU_epsilon_eps'
     lnU_epsilon_eps' 
     400*spread*lspreadU_epsilon_eps' 
     aU_epsilon_eps'];
time=0:1:size(ctw_epsilonshock,2)-1;
for jj=1:1:size(ctw_epsilonshock,1),
subplot(5,3,jj)
plot(time,ctw_epsilonshock(jj,:),time,0*time,'--','LineWidth',2);
set(gca,'FontSize',11);
if jj<10
set(gca,'XTicklabel',[]);
end

title(varnames(jj,:));
axis tight;
end;  
suptitle('Stationary Technology Shock');
print -depsc -zbuffer impresp_epsilonshock
print -dpdf -zbuffer impresp_epsilonshock

% Investment specific technology shock
figure;
ctw_Upsilonshock=100*[data_RU_Upsilon_eps' 
     data_picU_Upsilon_eps'
     lylessdU_Upsilon_eps'
     lcU_Upsilon_eps'
     liU_Upsilon_eps'
     nxdivGDPU_Upsilon_eps' 
     lHU_Upsilon_eps'
     lintensity0U_Upsilon_eps'     
     (1-L)*lUnemprateU_Upsilon_eps'
     lavg_NashU_Upsilon_eps'
     lwbarU_Upsilon_eps'
     lSlevU_Upsilon_eps'
     lnU_Upsilon_eps' 
     400*spread*lspreadU_Upsilon_eps'    
     aU_Upsilon_eps'];
time=0:1:size(ctw_Upsilonshock,2)-1;
for jj=1:1:size(ctw_Upsilonshock,1),
subplot(5,3,jj)
plot(time,ctw_Upsilonshock(jj,:),time,0*time,'--','LineWidth',2);
set(gca,'FontSize',11);
if jj<10
set(gca,'XTicklabel',[]);
end

title(varnames(jj,:));
axis tight;
end;  
suptitle('Marginal Efficiency of Investment Shock');
print -depsc -zbuffer impresp_Upsilonshock
print -dpdf -zbuffer impresp_Upsilonshock

% Gamma shock technology shock
if exist('data_RU_gamma_eps')
    figure;
    ctw_gammashock=100*[data_RU_gamma_eps'
        data_picU_gamma_eps'
        lylessdU_gamma_eps'
        lcU_gamma_eps'
        liU_gamma_eps'
        nxdivGDPU_gamma_eps'
        lHU_gamma_eps'
        lintensity0U_gamma_eps'
        (1-L)*lUnemprateU_gamma_eps'
        lavg_NashU_gamma_eps'
        lwbarU_gamma_eps'
        lSlevU_gamma_eps'
        lnU_gamma_eps'
        400*spread*lspreadU_gamma_eps'
        aU_gamma_eps'];
    time=0:1:size(ctw_gammashock,2)-1;
    for jj=1:1:size(ctw_gammashock,1),
        subplot(5,3,jj)
        plot(time,ctw_gammashock(jj,:),time,0*time,'--','LineWidth',2);
        set(gca,'FontSize',11);
        if jj<10
            set(gca,'XTicklabel',[]);
        end

        title(varnames(jj,:));
        axis tight;
    end;
    suptitle('Entrepreneur Survival Probability Shock');
    print -depsc -zbuffer impresp_gammashock
    print -dpdf -zbuffer impresp_gammashock
end

% zetah shock 
figure;
ctw_zetahshock=100*[data_RU_zetah_eps' 
     data_picU_zetah_eps'
     lylessdU_zetah_eps'
     lcU_zetah_eps'
     liU_zetah_eps'
     nxdivGDPU_zetah_eps'
     lHU_zetah_eps'
     lintensity0U_zetah_eps'     
     (1-L)*lUnemprateU_zetah_eps'
     lavg_NashU_zetah_eps'
     lwbarU_zetah_eps'
     lSlevU_zetah_eps'
     lnU_zetah_eps' 
     400*spread*lspreadU_zetah_eps'
     aU_zetah_eps'];
time=0:1:size(ctw_zetahshock,2)-1;
for jj=1:1:size(ctw_zetahshock,1),
subplot(5,3,jj)
plot(time,ctw_zetahshock(jj,:),time,0*time,'--','LineWidth',2);
set(gca,'FontSize',11);
if jj<10
set(gca,'XTicklabel',[]);
end

title(varnames(jj,:));
axis tight;
end;  
suptitle('Labor Preference Shock');
print -depsc -zbuffer impresp_zetahshock
print -dpdf -zbuffer impresp_zetahshock

% sigma shock
if exist('data_RU_sigma_eps')
    figure;
    ctw_sigmashock=100*[data_RU_sigma_eps'
        data_picU_sigma_eps'
        lylessdU_sigma_eps'
        lcU_sigma_eps'
        liU_sigma_eps'
        nxdivGDPU_sigma_eps'
        lHU_sigma_eps'
        lintensity0U_sigma_eps'
        (1-L)*lUnemprateU_sigma_eps'
        lavg_NashU_sigma_eps'
        lwbarU_sigma_eps'
        lSlevU_sigma_eps'
        lnU_sigma_eps'
        400*spread*lspreadU_sigma_eps'
        aU_sigma_eps'];
    time=0:1:size(ctw_sigmashock,2)-1;
    for jj=1:1:size(ctw_sigmashock,1),
        subplot(5,3,jj)
        plot(time,ctw_sigmashock(jj,:),time,0*time,'--','LineWidth',2);
        set(gca,'FontSize',11);
        if jj<10
            set(gca,'XTicklabel',[]);
        end

        title(varnames(jj,:));
        axis tight;
    end;
    suptitle('Idiosyncratic Risk Shock');
    print -depsc -zbuffer impresp_sigmashock
    print -dpdf -zbuffer impresp_sigmashock
end

% taumx: markup imported input for export production
if exist('data_RU_taumx_eps')
    figure;
    ctw_sigmashock=100*[data_RU_taumx_eps'
        data_picU_taumx_eps'
        lylessdU_taumx_eps'
        lcU_taumx_eps'
        liU_taumx_eps'
        nxdivGDPU_taumx_eps'
        lHU_taumx_eps'
        lintensity0U_taumx_eps'
        (1-L)*lUnemprateU_taumx_eps'
        lavg_NashU_taumx_eps'
        lwbarU_taumx_eps'
        lSlevU_taumx_eps'
        lnU_taumx_eps'
        400*spread*lspreadU_taumx_eps'
        aU_taumx_eps'];
    time=0:1:size(ctw_sigmashock,2)-1;
    for jj=1:1:size(ctw_sigmashock,1),
        subplot(5,3,jj)
        plot(time,ctw_sigmashock(jj,:),time,0*time,'--','LineWidth',2);
        set(gca,'FontSize',11);
        if jj<10
            set(gca,'XTicklabel',[]);
        end

        title(varnames(jj,:));
        axis tight;
    end;
    suptitle('Markup shock imported export inputs');
    print -depsc -zbuffer impresp_sigmashock
    print -dpdf -zbuffer impresp_sigmashock
end
