% Function to plot Smoothed estimates of exogenous unobserved processes
% in the CTW model, specification with 19 shock
% Needs to be adjusted manually if the vector of shocks changes

function exo_plotter_CTW_2010q3(oo_)

global M_;

% assigning values to params needed to plot s.s. values

mupsi       	=	M_.params(	21	);
etag        	=	M_.params(	52	);
muz             =	M_.params(	70	);
ybar            =	M_.params(	71	);
sigma       	=	M_.params(	191	);
gamma       	=	M_.params(	192	);
eta         	=	M_.params(	205	);

FIRST_YEAR=1995; % should it be first obs, or one period before?

%%load estimation_period
BEG_EST = 1 ;
END_EST = 62;

T=(FIRST_YEAR+BEG_EST/4:0.25:FIRST_YEAR+END_EST/4)';

% Create figure
figure1 = figure('PaperSize',[20.98 29.68]);
%title('Smoothed estimates of exogenous unobserved processes');

% Create subplot
subplot1 = subplot(5,3,14,'Parent',figure1);
box('on');
hold('all');

% Create plot
plot(T,exp(oo_.SmoothedVariables.lmuzU)*muz,'k',T,muz);
title('$\mu_z$','Interpreter','latex','Fontsize',18);
axis tight
set(gca,'Fontsize',12,'XTick',[1996;2002;2008]);

% % Create subplot
% subplot2 = subplot(4,5,16,'Parent',figure1);
% box('on');
% hold('all');
% 
% % Create plot
% plot(T,exp(oo_.SmoothedVariables.lmupsiU)*mupsi,T,mupsi);
% title('Mupsi');

% Create subplot
subplot3 = subplot(5,3,1,'Parent',figure1);
box('on');
hold('all');

% Create plot
plot(T,exp(oo_.SmoothedVariables.lepsilonU),'k',T,1);
title('$\epsilon$','Interpreter','latex','Fontsize',18);
axis tight
set(gca,'Fontsize',12,'XTick',[1996;2002;2008]);

% Create subplot
subplot4 = subplot(5,3,2,'Parent',figure1);
box('on');
hold('all');

% Create plot
plot(T,exp(oo_.SmoothedVariables.lUpsilonU),'k',T,1);
title('$\Upsilon$','Interpreter','latex','Fontsize',18);
axis tight
set(gca,'Fontsize',12,'XTick',[1996;2002;2008]);

% Create subplot
subplot5 = subplot(5,3,3,'Parent',figure1);
box('on');
hold('all');

% Create plot
plot(T,exp(oo_.SmoothedVariables.lzetacU),'k',T,1);
title('$\zeta^c$','Interpreter','latex','Fontsize',18);
axis tight
set(gca,'Fontsize',12,'XTick',[1996;2002;2008]);

% Create subplot
subplot6 = subplot(5,3,13,'Parent',figure1);
box('on');
hold('all');

% Create plot
plot(T,oo_.SmoothedVariables.phitildeU,'k',T,0);
title('$\tilde{\phi}$','Interpreter','latex','Fontsize',18);
axis tight
set(gca,'Fontsize',12,'XTick',[1996;2002;2008]);

% Note that R, below, are observed and therefore plotted
% anyway. Also, this is not an exog. process
% % Create subplot
subplot6 = subplot(5,3,5,'Parent',figure1);
box('on');
hold('all');

% Create plot
plot(T,oo_.SmoothedShocks.epsR_eps,'k',T,0);  
title('$\epsilon_R$','Interpreter','latex','Fontsize',18);
axis tight
set(gca,'Fontsize',12,'XTick',[1996;2002;2008]);

% Create subplot
subplot7 = subplot(5,3,6,'Parent',figure1);
box('on');
hold('all');

% Create plot
plot(T,exp(oo_.SmoothedVariables.lgU)*etag,'k', T, etag);
title('$g$','Interpreter','latex','Fontsize',18)
axis tight
set(gca,'Fontsize',12,'XTick',[1996;2002;2008]);

% Create subplot
subplot8 = subplot(5,3,7,'Parent',figure1);
box('on');
hold('all');

% Create plot
plot(T,exp(oo_.SmoothedVariables.ltaudU),'k',T,1);
title('$\tau^d$','Interpreter','latex','Fontsize',18);
axis tight
set(gca,'Fontsize',12,'XTick',[1996;2002;2008]);

% Create subplot
subplot9 = subplot(5,3,8,'Parent',figure1);
box('on');
hold('all');

% Create plot
plot(T,exp(oo_.SmoothedVariables.ltauxU),'k',T,1);
title('$\tau^x$','Interpreter','latex','Fontsize',18);
axis tight
set(gca,'Fontsize',12,'XTick',[1996;2002;2008]);

% Create subplot
subplot10 = subplot(5,3,9,'Parent',figure1);
box('on');
hold('all');

% Create plot
plot(T,exp(oo_.SmoothedVariables.ltaumcU),'k',T,1);
title('$\tau^{mc}$','Interpreter','latex','Fontsize',18);
axis tight
set(gca,'Fontsize',12,'XTick',[1996;2002;2008]);

% Create subplot
subplot11 = subplot(5,3,10,'Parent',figure1);
box('on');
hold('all');

% Create plot
plot(T,exp(oo_.SmoothedVariables.ltaumiU),'k',T,1);
title('$\tau^{mi}$','Interpreter','latex','Fontsize',18);
axis tight
set(gca,'Fontsize',12,'XTick',[1996;2002;2008]);

% Create subplot
subplot12 = subplot(5,3,11,'Parent',figure1);
box('on');
hold('all');

% Create plot
plot(T,exp(oo_.SmoothedVariables.ltaumxU),'k',T,1);
title('$\tau^{mx}$','Interpreter','latex','Fontsize',18);
axis tight
set(gca,'Fontsize',12,'XTick',[1996;2002;2008]);

% Create subplot
subplot13 = subplot(5,3,12,'Parent',figure1);
box('on');
hold('all');

% Create plot
plot(T,exp(oo_.SmoothedVariables.lgammaU)*gamma,'k',T,gamma);
title('$\gamma$','Interpreter','latex','Fontsize',18);
axis tight
set(gca,'Fontsize',12,'XTick',[1996;2002;2008]);

% % Create subplot
% subplot16 = subplot(5,3,15,'Parent',figure1);
% box('on');
% hold('all');
% 
% Create plot
% plot(T,exp(oo_.SmoothedVariables.lsigmaU)*sigma,'k',T,sigma);
% title('sigma');
% axis tight

% Create subplot
subplot15 = subplot(5,3,4,'Parent',figure1);
box('on');
hold('all');
plot(T,exp(oo_.SmoothedVariables.lzetahU),'k',T,1);
title('$\zeta^h$','Interpreter','latex','Fontsize',18);
axis tight
set(gca,'Fontsize',12,'XTick',[1996;2002;2008]);

%suptitle('Smoothed Shock Processes');
print -depsc -zbuffer Shock_Processes
print -dpdf Shock_Processes

% Note that Foreign variables, below, are observed and therefore plotted
% anyway
% % Create subplot
% subplot16 = subplot(5,3,16,'Parent',figure1);
% box('on');
% hold('all');
% 
% % Create plot
% plot(T,oo_.SmoothedVariables.lystarU);
% title('ystar');
% 
% % Create subplot
% subplot17 = subplot(5,3,17,'Parent',figure1);
% box('on');
% hold('all');
% 
% % Create plot
% plot(T,oo_.SmoothedVariables.lpistarU);
% title('pistar');
% 
% % Create subplot
% subplot18 = subplot(5,3,18,'Parent',figure1);
% box('on');
% hold('all');
% 
% % Create plot
% plot(T,oo_.SmoothedVariables.lRstarU);
% title('Rstar');
